#!/usr/bin/perl
use strict;
use warnings;
use Getopt::Long qw(:config no_ignore_case);

if (!-e "Makefile") {
    print "Execute me from the source directory!\n";
    exit 1;
}

my $o_prefix           = "/usr/local";
my $o_confdir          = "/etc";
my $o_logdir           = "/var/log";
my $o_perl             = "/usr/bin/perl";
my $o_instdirs         = "site";
my $o_help             = 0;
my $o_perl_prefix      = "/usr/local";
my $o_perl_installdirs = "site";
my $o_without_perl     = 0;

GetOptions(
    "prefix=s"           => \$o_prefix,
    "logdir=s"           => \$o_logdir,
    "perl=s"             => \$o_perl,
    "h|help"             => \$o_help,
    "perl-prefix=s"      => \$o_perl_prefix,
    "perl-installdirs=s" => \$o_perl_installdirs,
    "without-perl"       => \$o_without_perl,
);

if ($o_help) {
    print "Usage: perl Configure.PL [ OPTIONS ]\n\n";
    print "Configure options:\n\n";
    print "  --prefix DIR\n";
    print "  --confdir DIR\n";
    print "  --logdir DIR\n";
    print "  --perl PERL EXECUTABLE\n";
    print "  --perl-prefix DIR\n";
    print "  --perl-installdirs INSTALLDIRS\n";
    print "  --without-perl\n";
    print "\n";
    exit 0;
}

open my $fh, ">", "Makefile.config" or die "Unable to overwrite Makefile - $!";

print "Writing Makefile.config ...\n";

print $fh <<EOF;
# Base paths
PREFIX=\$(DESTDIR)$o_prefix
CONFDIR=\$(DESTDIR)$o_confdir
LOGDIR=\$(DESTDIR)$o_logdir
PERL=$o_perl
PERL_PREFIX=\$(DESTDIR)$o_perl_prefix
PERL_INSTALLDIRS=$o_perl_installdirs
WITHOUT_PERL=$o_without_perl
EOF

close $fh;

print "Done.\n";
